@@ -1,6 +1,12 @@
-#![ warn( missing_docs ) ]
+#![ warn( rust_2018_idioms ) ]
 #![ warn( missing_debug_implementations ) ]
-// #![ feature( concat_idents ) ]
+#![ warn( missing_docs ) ]
+
+/* qqq : for Dima : wrong header */
+
+// #![ warn( rust_2018_idioms ) ]
+// #![ warn( missing_debug_implementations ) ]
+// #![ warn( missing_docs ) ]
 
 //!
 //! wTools - Collection of general purpose tools for solving problems. Fundamentally extend the language without spoiling, so may be used solely or in conjunction with another module of such kind.
@@ -30,6 +36,12 @@ pub use meta::*;
 pub mod typing;
 pub use typing::*;
 
+///
+/// Collection of primal data types
+///
+
+pub mod dt;
+
 // ///
 // /// Exporting/importing serialize/deserialize encoding/decoding macros, algorithms and structures for that.
 // ///
@@ -89,7 +101,7 @@ pub mod dependencies
 
 }
 
-// xxx : try to use instead of feature::nightly
+// zzz : try to use instead of feature::nightly
 // #![cfg_attr(feature = "nightly", feature(unsize))]
 
 // /// Internal namespace.
@@ -184,4 +196,4 @@ pub mod dependencies
 //
 //   own X2;
 //
-// }
\ No newline at end of file
+// }
